sdv.metadata.dataset.Metadata
=============================

.. currentmodule:: sdv.metadata.dataset

.. autoclass:: Metadata

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Metadata.__init__
      ~Metadata.add_field
      ~Metadata.add_relationship
      ~Metadata.add_table
      ~Metadata.get_children
      ~Metadata.get_dtypes
      ~Metadata.get_field_meta
      ~Metadata.get_fields
      ~Metadata.get_foreign_keys
      ~Metadata.get_parents
      ~Metadata.get_primary_key
      ~Metadata.get_table_meta
      ~Metadata.get_tables
      ~Metadata.load_table
      ~Metadata.load_tables
      ~Metadata.reverse_transform
      ~Metadata.set_primary_key
      ~Metadata.to_dict
      ~Metadata.to_json
      ~Metadata.transform
      ~Metadata.validate
      ~Metadata.visualize
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Metadata.root_path
   
   